@@ -2252,7 +2252,7 @@ class remotePhoneAccess:
         self.axlUsername = axlUsername
         self.axlPassword = axlPassword
         self.server_ip = server_ip
-        ConnectivityTest = (self.session.get(f'https://{self.axlUsername}:{self.axlPassword}@{self.phone_ip}'))
+        ConnectivityTest = (requests.get(f'https://{self.axlUsername}:{self.axlPassword}@{self.phone_ip}', verify=False))
         if ConnectivityTest.status_code == 200:
             logging.info(f'Successfully connected to Phone: {self.phone_ip}')
         elif ConnectivityTest.status_code == 401:
